UmamiTeamService class

Service for team operations with the Umami API.

Constructors

UmamiTeamService({required String endpoint})
Creates an instance of UmamiTeamService.

Properties

endpoint String
Base endpoint of the Umami API.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addUserToTeam({required String token, required String teamId, required String userId, required String role}) Future<Map<String, dynamic>?>
Adds a user to the team.
createTeam({required String token, required String name}) Future<List?>
Creates a new team.
deleteTeam({required String token, required String teamId}) Future<bool>
Deletes a team.
getTeamById({required String token, required String teamId}) Future<Map<String, dynamic>?>
Gets a team by ID.
getTeamUserById({required String token, required String teamId, required String userId}) Future<Map<String, dynamic>?>
Gets a user from a team.
getTeamUsers({required String token, required String teamId, String? query, int? page, int? pageSize, String? orderBy}) Future<Map<String, dynamic>?>
Lists all users of a team.
getTeamWebsites({required String token, required String teamId, String? query, int? page, int? pageSize, String? orderBy}) Future<List?>
Gets all websites of a team.
joinTeam({required String token, required String accessCode}) Future<List?>
Join a team using the accessCode.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeUserFromTeam({required String token, required String teamId, required String userId}) Future<bool>
Removes a user from the team.
toString() String
A string representation of this object.
inherited
updateTeam({required String token, required String teamId, String? name, String? accessCode}) Future<Map<String, dynamic>?>
Updates a team.
updateTeamUserRole({required String token, required String teamId, required String userId, required String role}) Future<bool>
Updates the role of a user in the team.

Operators

operator ==(Object other) bool
The equality operator.
inherited